django-planet
=============

.. image:: https://travis-ci.org/matagus/django-planet.png
   :alt: Build Status (by travis.ci)
   :target: https://travis-ci.org/matagus/django-planet

.. image:: https://coveralls.io/repos/matagus/django-planet/badge.png
   :target: https://coveralls.io/r/matagus/django-planet

.. image:: https://d2weczhvl823v0.cloudfront.net/matagus/django-planet/trend.png
   :alt: Bitdeli badge
   :target: https://bitdeli.com/free

This is a generic application for Django projects aiming to provide a planet
feed aggregator app.

It is compatible with `Pinax <http://pinaxproject.com/>`_ and its themed using `Twitter Bootstrap <http://twitter.github.com/bootstrap/>`_
and `Wave-Grind pattern as background from subtlepatter.com <http://subtlepatterns.com/wave-grind/>`_.

Django-planet is heavily based on `Feedjack's <http://www.feedjack.org/>`_ models by Gustavo Picon and my
django app that extends it: `feedjack-extension <http://code.google.com/p/feedjack-extension/>`_. Changes and addings to
models were inspired by `Mark Pilgrim's Feedparser <http://www.feedparser.org/>`_.

Screenshots:
------------

The following screenshots are just for demonstration purposes:

.. image:: https://raw.github.com/matagus/django-planet/master/screenshots/latest-posts.png

.. image:: https://raw.github.com/matagus/django-planet/master/screenshots/post-view.png

.. image:: https://raw.github.com/matagus/django-planet/master/screenshots/tag-view.png

INSTALLATION
------------

    * For installation instructions, see the file INSTALL in this directory.

Contribute
----------

- `Issue Tracker <https://github.com/matagus/django-planet/issues>`_
- `Source Code <https://github.com/matagus/django-planet>`_

Support
-------

If you are having issues, please let me know. Drop me an email to matagus at 
gmail dot com.

License
-------

The project is licensed under the BSD license.

DEMO
----

There is a `simple demo django-planet <http://django-planet.herokuapp.com/>`_ at heroku.com.
